/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.launcher.api.server.conf;

import java.io.File;

/**
 * This class is the list of all available property names to configure locally a
 * container (ie. all properties contained in the file '
 * <code>server.properties</code>') and their default values.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ConfigurationProperties {

    /**
     * Name of the property defining the configuration file of the logging
     * system
     */
    public static final String LOGGING_SYSTEM_CONF_FILE_PROPERTY_NAME = "petals.container.log.config.file";

    /**
     * Default file name of the configuration file of the logging system
     */
    public final static String DEFAULT_LOGGER_FILENAME = "loggers.properties";

    /**
     * Name of the property defining the container name.
     */
    public static final String CONTAINER_NAME = "petals.container.name";

    /**
     * Name of the property defining the root directory containing all data of
     * the Petals ESB container
     */
    public static final String DATA_ROOT_DIRECTORY_PROPERTY_NAME = "petals.data.basedir";

    /**
     * Name of the property defining the directory associated to the internal
     * repository containing all deployed artifacts (SL, BC/SE, SA)
     */
    public static final String REPOSITORY_PATH_PROPERTY_NAME = "petals.repository.path";

    /**
     * Default value of the directory used as repository containing all deployed
     * artifacts.
     */
    public static final String DEFAULT_REPOSITORY_PATH = "${" + DATA_ROOT_DIRECTORY_PROPERTY_NAME
            + "}" + File.separator + "repository";

    /**
     * Name of the property defining the directory associated to working area
     */
    public static final String WORKING_AREA_PATH_PROPERTY_NAME = "petals.work.path";

    /**
     * Default value of the directory used as working area.
     */
    public static final String DEFAULT_WORKING_AREA_PATH = "${" + DATA_ROOT_DIRECTORY_PROPERTY_NAME
            + "}" + File.separator + "work";

    /**
     * Name of the property defining the topology passphrase
     */
    public static final String TOPOLOGY_PASSPHRASE = "petals.topology.passphrase";

    /**
     * Name of the property defining the dynamic topology lock wait time
     */
    public static final String TOPOLOGY_LOCKS_MAX_WAIT_TIME = "petals.topology.locks.max-wait-time";

    /**
     * Name of the property defining the waiting time before to start the topology pinger
     */
    public static final String TOPOLOGY_PINGER_START_DELAY = "petals.topology.pinger.start-delay";

    /**
     * Name of the property defining the delay between two runs of the topology pinger
     */
    public static final String TOPOLOGY_PINGER_PERIOD_DELAY = "petals.topology.pinger.period-delay";

    public static final String EXCHANGE_VALIDATION = "petals.exchange.validation";

    public static final String ROUTER_QOS = "petals.router.qos";

    /**
     * Name of the property defining the routing strategy
     */
    public static final String ROUTER_STRATEGY = "petals.router.strategy";

    public static final String ROUTER_SEND_ATTEMPT = "petals.router.send.attempt";

    public static final String ROUTER_SEND_DELAY = "petals.router.send.delay";

    public static final String ROUTER_STOP_TRAFFIC_DELAY = "petals.router.traffic.stop.delay";

    public static final String ROUTER_PAUSE_TRAFFIC_DELAY = "petals.router.traffic.pause.delay";

    /**
     * Name of the property defining the maximum duration of the processing of a life-cycle operation
     */
    public static final String TASK_TIMEOUT = "petals.task.timeout";

    /**
     * Name of the property enabling/disabling the classloader isolation
     */
    public static final String CLASSLOADER_ISOLATED = "petals.classloaders.isolated";

    public static final String SSL_KEY_PASSWORD = "petals.ssl.key.password";

    public static final String SSL_KEYSTORE_FILE = "petals.ssl.keystore.file";

    public static final String SSL_KEYSTORE_PASSWORD = "petals.ssl.keystore.password";

    public static final String SSL_TRUSTSTORE_FILE = "petals.ssl.truststore.file";

    public static final String SSL_TRUSTSTORE_PASSWORD = "petals.ssl.truststore.password";

    /**
     * Name of the property defining the max size of the transporter queues.
     */
    public static final String TRANSPORT_QUEUE_MAXSIZE = "petals.transport.queue.max-size";

    /**
     * Name of the property defining the offering timeout of component
     * transporter queues
     */
    public static final String TRANSPORT_QUEUE_OFFERING_TIMEOUT = "petals.transport.queue.offering.timeout";

    /**
     * Name of the property defining the networks interface on which connection and data are received by TCP receivers.
     */
    public static final String TRANSPORT_TCP_LISTEN = "petals.transport.tcp.receivers.listening.interface";

    /**
     * Name of the property defining the number of message that can be received
     * via TCP at the same time
     */
    public static final String TRANSPORT_TCP_RECEIVERS = "petals.transport.tcp.receivers";

    /**
     * Name of the property defining the keep alive time before to stop unused TCP receivers
     */
    public static final String TRANSPORT_TCP_RECEIVER_KEEP_ALIVE_TIME = "petals.transport.tcp.receiver.keep-alive";

    /**
     * Name of the property defining the number of message that can be send via TCP at the same time, per component
     */
    public static final String TRANSPORT_TCP_SENDERS = "petals.transport.tcp.senders";

    /**
     * Name of the property defining the TCP Connection timeout of the remote
     * transporter
     */
    public static final String TRANSPORT_TCP_CONNECTION_TIMEOUT = "petals.transport.tcp.connection.timeout";

    /**
     * Name of the property defining the TCP send timeout of the remote
     * transporter
     */
    public static final String TRANSPORT_TCP_SEND_TIMEOUT = "petals.transport.tcp.send.timeout";

    /**
     * Name of the property defining the delay before running the 'sender'
     * eviction thread of the remote transporter
     */
    public static final String TRANSPORT_TCP_SEND_EVICTOR_DELAY = "petals.transport.tcp.send.evictor.delay";

    /**
     * Name of the property defining the delay before an idle 'sender' of the
     * remote transporter is set evictable
     */
    public static final String TRANSPORT_TCP_SEND_EVICTABLE_DELAY = "petals.transport.tcp.send.evictable.delay";

    /**
     * Prefix of user properties
     */
    public static final String USER_CONFIG_PREFIX = "user";

    public static final String RECOVERY_CORE_POOL_SIZE = "petals.recovery.corepoolsize";

    public static final String RECOVERY_KEEP_ALIVE_TIME = "petals.recovery.keepalivetime";

}
